@@ -189,7 +189,11 @@ module RSpec::Puppet
           else
             a = type == :not ? '!' : '='
             b = value.is_a?(Regexp) ? '~' : '>'
-            output << "#{param.to_s} #{a}#{b} #{value.inspect}"
+            if param.to_s == 'content' and value.is_a?( String )
+              output << "#{param.to_s} #{type == :not ? 'not ' : ''} supplied string"
+            else
+              output << "#{param.to_s} #{a}#{b} #{value.inspect}"
+            end
           end
         end
         output
@@ -227,32 +231,84 @@ module RSpec::Puppet
         end
       end
 
-      def relationship_refs(array)
-        Array[array].flatten.map do |resource|
-          resource.respond_to?(:to_ref) ? resource.to_ref : resource
+      def resource_ref(resource)
+        resource.respond_to?(:to_ref) ? resource.to_ref : resource
+      end
+
+      def resource_from_ref(ref)
+        ref.is_a?(Puppet::Resource) ? ref : @catalogue.resource(ref)
+      end
+
+      def canonicalize_resource(resource)
+        resource_from_ref(resource_ref(resource))
+      end
+
+      def canonicalize_resource_ref(ref)
+        resource_ref(resource_from_ref(ref))
+      end
+
+      def relationship_refs(resource, type)
+        resource = canonicalize_resource(resource)
+        results = []
+        return results unless resource
+        Array[resource[type]].flatten.compact.each do |r|
+          results << canonicalize_resource_ref(r)
+          results << relationship_refs(r, type)
         end
+
+        # Add autorequires if any
+        if type == :require and resource.resource_type.respond_to? :eachautorequire
+          resource.resource_type.eachautorequire do |t, b|
+            Array(resource.to_ral.instance_eval(&b)).each do |dep|
+              res = "#{t.to_s.capitalize}[#{dep}]"
+              if r = relationship_refs(res, type)
+                results << res
+                results << r
+              end
+            end
+          end
+        end
+        results.flatten
+      end
+
+      def self_or_upstream(vertex)
+        [vertex] + @catalogue.upstream_from_vertex(vertex).keys
       end
 
       def precedes?(first, second)
-        if first.nil? || second.nil?
-          false
-        else
-          before_refs = relationship_refs(first[:before])
-          require_refs = relationship_refs(second[:require])
+        return false if first.nil? || second.nil?
 
-          before_refs.include?(second.to_ref) || require_refs.include?(first.to_ref)
+        self_or_upstream(first).each do |u|
+          self_or_upstream(second).each do |v|
+            before_refs = relationship_refs(u, :before)
+            require_refs = relationship_refs(v, :require)
+
+            if before_refs.include?(v.to_ref) || require_refs.include?(u.to_ref) || (before_refs & require_refs).any?
+              return true
+            end
+          end
         end
+
+        # Nothing found
+        return false
       end
 
       def notifies?(first, second)
-        if first.nil? || second.nil?
-          false
-        else
-          notify_refs = relationship_refs(first[:notify])
-          subscribe_refs = relationship_refs(second[:subscribe])
+        return false if first.nil? || second.nil?
 
-          notify_refs.include?(second.to_ref) || subscribe_refs.include?(first.to_ref)
+        self_or_upstream(first).each do |u|
+          self_or_upstream(second).each do |v|
+            notify_refs = relationship_refs(u, :notify)
+            subscribe_refs = relationship_refs(v, :subscribe)
+
+            if notify_refs.include?(v.to_ref) || subscribe_refs.include?(u.to_ref)
+              return true
+            end
+          end
         end
+
+        # Nothing found
+        return false
       end
 
       # @param resource [Hash<Symbol, Object>] The resource in the catalog
