@@ -10,7 +10,9 @@ describe 'split' do
     expected_error = Puppet::ParseError
   end
 
-  if Puppet.version.to_f >= 4.0
+  if Puppet.version.to_f >= 4.3
+    expected_error_message = /expects \d+ arguments/
+  elsif Puppet.version.to_f >= 4.0
     expected_error_message = /mis-matched arguments/
   else
     expected_error_message = /number of arguments/
@@ -21,4 +23,11 @@ describe 'split' do
   it { should run.with_params('foo').and_raise_error(expected_error, expected_error_message) }
 
   it { should run.with_params('foo').and_raise_error(expected_error_message) }
+
+  it { expect { should run.with_params('foo').and_raise_error(/definitely no match/) }.to raise_error RSpec::Expectations::ExpectationNotMetError }
+
+  context 'after including a class' do
+    let(:pre_condition) { 'include ::sysctl::common' }
+    it { should run.with_params('aoeu', 'o').and_return(['a', 'eu']) }
+  end
 end
